@@ -33,15 +33,16 @@ from construct import (
     PaddedString,
     Select,
     Struct,
-    Switch,
     this,
 )
 
+from bluetooth_mesh.messages.util import EnumAdapter
+from bluetooth_mesh.messages.util import EnumSwitch as Switch
 from bluetooth_mesh.messages.util import (
-    EnumAdapter,
     IpAddressAdapter,
     MacAddressAdapter,
     Opcode,
+    SwitchStruct,
 )
 
 
@@ -184,9 +185,9 @@ ConfigurationSetWithOptionalDhcpDisabled = Struct(
 )
 
 ConfigurationSet = Select(
-    ConfigurationSetWithOptionalDhcpDisabled,
-    ConfigurationSetWithOptionalDhcpEnabledWithStaticDns,
-    ConfigurationSetWithoutOptionalAutoDhcpEnabled,
+    static=ConfigurationSetWithOptionalDhcpDisabled,
+    dns=ConfigurationSetWithOptionalDhcpEnabledWithStaticDns,
+    minimal=ConfigurationSetWithoutOptionalAutoDhcpEnabled,
 )
 
 ConfigurationStatus = Struct(
@@ -196,21 +197,23 @@ ConfigurationStatus = Struct(
     "status_code" / EnumAdapter(Int8ul, StatusCode),
 )
 
+ConnectionState = BitStruct(
+    "conn_state" / EnumAdapter(BitsInteger(3), ConnState),
+    "link_status" / EnumAdapter(BitsInteger(1), LinkStatus),
+    "last_error" / EnumAdapter(BitsInteger(4), LastError)
+)
+
 # GATEWAY PACKETS MSG
 PacketsStatus = Struct(
     "total_eth_rx_errors" / Int16ul,
     "total_eth_tx_errors" / Int16ul,
     "bandwidth" / Int16ul,
-    "connection_state" / BitStruct(
-        "conn_state" / EnumAdapter(BitsInteger(3), ConnState),
-        "link_status" / EnumAdapter(BitsInteger(1), LinkStatus),
-        "last_error" / EnumAdapter(BitsInteger(4), LastError)
-    )
+    "connection_state" / ConnectionState,
 )
 
-GatewayConfigPayload = Struct(
+GatewayConfigParams = SwitchStruct(
     "subopcode" / EnumAdapter(Int8ul, GatewayConfigServerSubOpcode),
-    "payload" / Default(Switch(
+    "payload" / Switch(
         this.subopcode,
         {
             GatewayConfigServerSubOpcode.GATEWAY_CONFIGURATION_SET: ConfigurationSet,
@@ -225,11 +228,16 @@ GatewayConfigPayload = Struct(
             GatewayConfigServerSubOpcode.GATEWAY_CONFIGURATION_STATUS: ConfigurationStatus,
             GatewayConfigServerSubOpcode.GATEWAY_PACKETS_STATUS: PacketsStatus,
         },
-    ), None)
+    )
 )
 
-GatewayConfigMessage = Struct(
-    "opcode" / Const(GatewayConfigServerOpcode.SILVAIR_GATEWAY, Opcode(GatewayConfigServerOpcode)),
-    "params" / GatewayConfigPayload
+GatewayConfigMessage = SwitchStruct(
+    "opcode" / Opcode(GatewayConfigServerOpcode),
+    "params" / Switch(
+        this.opcode,
+        {
+            GatewayConfigServerOpcode.SILVAIR_GATEWAY: GatewayConfigParams
+        }
+    )
 )
 # fmt: on
