@@ -27,10 +27,28 @@ from concurrent.futures._base import CancelledError
 from contextlib import suppress
 from functools import wraps
 from inspect import isawaitable
-from typing import Any, Callable, Hashable, Iterable, Mapping, Optional, TypeVar, Awaitable, Dict, Tuple
+from typing import (
+    Any,
+    Awaitable,
+    Callable,
+    Dict,
+    Hashable,
+    Iterable,
+    Mapping,
+    Optional,
+    Tuple,
+    TypeVar,
+)
 
 from typing_extensions import Protocol
 
+try:
+    from asyncio import create_task
+except ImportError:
+    from asyncio import ensure_future
+
+    create_task = ensure_future
+
 ParsedMeshMessage = Mapping[str, Any]
 MessageDescription = Mapping[str, Any]
 ProgressCallback = Callable[[Hashable, Any, Mapping, Mapping], None]
@@ -87,15 +105,15 @@ class Signal:
 
 class Gatherer:
     """
-        Gather tasks as they are done and return them in asynchronous iterator form.
+    Gather tasks as they are done and return them in asynchronous iterator form.
 
-        :param aws: iterable collection of tasks
-        :param timeout: Timeout in seconds of None for no timeout
-        :param loop: asyncio loop or None
+    :param aws: iterable collection of tasks
+    :param timeout: Timeout in seconds of None for no timeout
+    :param loop: asyncio loop or None
 
-        :return: A tuple of:
-            - task to collect
-            - result of the task
+    :return: A tuple of:
+        - task to collect
+        - result of the task
     """
 
     def __init__(self, aws: Iterable, timeout: int = None, loop=None):
@@ -205,8 +223,9 @@ def tasklet(coro: AnyCoroutine) -> Respawn:
             handle.cancel()
             await handle
 
-        return handles.setdefault(key, respawn.loop.create_task(coro(*args, **kwargs)))
+        return handles.setdefault(key, create_task(coro(*args, **kwargs)))
 
-    respawn.group_by = lambda *args, **kwargs: 1  # All tasks belong to one group by default
-    respawn.loop = asyncio.get_event_loop()
+    respawn.group_by = (
+        lambda *args, **kwargs: 1
+    )  # All tasks belong to one group by default
     return respawn
